Crate pkgar_keys

Crate pkgar_keys 

Structs

Passwd
Secure in-memory representation of a password.
PublicKeyFile
Standard pkgar public key format definition. Use serde to serialize/deserialize files into this struct (helper methods available).
SecretKeyFile
Standard pkgar private key format definition. Use serde. Internally, this struct stores the encrypted state of the private key as an enum. Manipulate the state using the encrypt(), decrypt() and is_encrypted().

Enums

Error

Functions

get_skey
Get a SecretKeyFile from a path. If the file is encrypted and “cli” feature enabled, prompt for a password on stdin. Without “cli” feature the secret file will remain encypted as equivalent to calling SecretKeyFile::open.