SecretKeyFile

Struct SecretKeyFile 

pub struct SecretKeyFile { /* private fields */ }
Standard pkgar private key format definition. Use serde. Internally, this struct stores the encrypted state of the private key as an enum. Manipulate the state using the encrypt(), decrypt() and is_encrypted().

Implementations

Source

impl SecretKeyFile

pub fn new() -> (PublicKeyFile, SecretKeyFile)

Generate a keypair with all the nessesary info to save both keys. You must call save() on each object to persist them to disk.

pub fn open(file: impl AsRef<Path>) -> Result<SecretKeyFile, Error>

Parse a SecretKeyFile from file (in toml format).

pub fn write(&self, w: impl Write) -> Result<(), Error>

Write self serialized as toml to w.

pub fn save(&self, file: impl AsRef<Path>) -> Result<(), Error>

Shortcut to write the secret key to file.

Make sure to call encrypt() in order to encrypt the private key, otherwise it will be stored as plain text.

pub fn encrypt(&mut self, passwd: Passwd) -> Result<(), Error>

Ensure that the internal state of this struct is encrypted. Note that if passwd is empty, this function is a no-op.

pub fn decrypt(&mut self, passwd: Passwd) -> Result<(), Error>

Ensure that the internal state of this struct is decrypted. If the internal state is already decrypted, this function is a no-op.

pub fn is_encrypted(&self) -> bool

Status of the internal state.

pub fn secret_key(&self) -> Option<SecretKey>

Returns None if the secret key is encrypted.

pub fn public_key(&self) -> Option<PublicKey>

Returns None if the secret key is encrypted.

pub fn public_key_file(&self) -> Option<PublicKeyFile>

Returns None if the secret key is encrypted.