Standard pkgar private key format definition. Use serde.
Internally, this struct stores the encrypted state of the private key as an enum.
Manipulate the state using the encrypt(), decrypt() and is_encrypted().
Get a SecretKeyFile from a path. If the file is encrypted and “cli” feature enabled, prompt for a password on stdin.
Without “cli” feature the secret file will remain encypted as equivalent to calling SecretKeyFile::open.